/*
 *
 * Copyright (c) 2006-2019, Speedment, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); You may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at:
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.speedment.runtime.compute.internal.predicate;

import com.speedment.runtime.compute.expression.predicate.IsNotNull;
import com.speedment.runtime.compute.expression.predicate.IsNull;
import com.speedment.runtime.compute.trait.ToNullable;

import static java.util.Objects.requireNonNull;

/**
 * Default implementation of the {@link IsNull}-interface.
 *
 * @author Emil Forslund
 * @since  3.1.2
 */
public final class IsNullImpl<T, R> implements IsNull<T, R> {

    private final ToNullable<T, R, ?> expression;

    public IsNullImpl(ToNullable<T, R, ?> expression) {
        this.expression = requireNonNull(expression);
    }

    @Override
    public IsNotNull<T, R> negate() {
        return new IsNotNullImpl<>(expression);
    }

    @Override
    public ToNullable<T, R, ?> expression() {
        return expression;
    }
}
